EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_CreateFeed',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Feed_Id',
    /* Description_Text        */ 'Creates a new feed of the specified type.'
GO

IF OBJECT_ID('[Feeds_CreateOrUpdateBowerFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateBowerFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateDockerFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateDockerFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateMavenFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateMavenFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateNpmFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateNpmFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateNuGetFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateNuGetFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateProGetFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateProGetFeed]
IF OBJECT_ID('[Feeds_CreateOrUpdateRubyGemsFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateOrUpdateRubyGemsFeed]
GO

IF OBJECT_ID('[Feeds_CreateFeed]') IS NOT NULL DROP PROCEDURE [Feeds_CreateFeed]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_CreateFeed]
(
	@Feed_Name NVARCHAR(50),
	@FeedType_Name VARCHAR(20),
	@FeedConfiguration_Xml XML,
	@Feed_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Feeds]
	(
		[Feed_Name],
		[Active_Indicator],
		[Cache_Connectors_Indicator],
		[FeedType_Name],
		[AllowUnknownLicenses_Indicator],
		[FeedConfiguration_Xml]
	)
	VALUES
	(
		@Feed_Name,
		'Y',
		'Y',
		@FeedType_Name,
		'Y',
		@FeedConfiguration_Xml
	)

	SET @Feed_Id = SCOPE_IDENTITY()

	EXEC [Events_RaiseEvent] 'FEDNWF', @Feed_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Feeds_CreateFeed] TO [ProGetUser_Role]
GO