EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'HelmChartDockerImages_CreateImage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a link to a Docker Image from a chart in a Helm feed.'
GO

IF OBJECT_ID('[HelmChartDockerImages_CreateImage]') IS NOT NULL DROP PROCEDURE [HelmChartDockerImages_CreateImage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [HelmChartDockerImages_CreateImage]
(
	@DockerRepository_Name VARCHAR(255),
	@Tag_Name VARCHAR(255),
	@DockerFeed_Id INT,
	@Chart_Name VARCHAR(200),
	@Chart_Version_Text VARCHAR(200),
	@Chart_Feed_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION	
			DECLARE @DockerRepository_Id  int
			SET @DockerRepository_Id = (SELECT TOP 1 [DockerRepository_Id] FROM [DockerRepositories] WHERE [Repository_Name] = @DockerRepository_Name AND [Feed_Id] = @DockerFeed_Id)
			
			
				INSERT INTO [HelmChartDockerImages]
				(
					[DockerRepository_Id],
					[Repository_Name],
					[Tag_Name],
					[DockerFeed_Id],
					[Chart_Name],
					[Chart_Version_Text],
					[Chart_Feed_Id]
				)
				VALUES
				(
					@DockerRepository_Id,
					@DockerRepository_Name,
					@Tag_Name,
					@DockerFeed_Id,
					@Chart_Name,
					@Chart_Version_Text,
					@Chart_Feed_Id
				)	
			
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [HelmChartDockerImages_CreateImage] TO [ProGetUser_Role]
GO
