EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_GetVulnerabilities',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Vulnerabilities_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a list of known vulnerabilities.'
GO

IF OBJECT_ID('[Vulnerabilities_GetVulnerabilities]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_GetVulnerabilities]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Vulnerabilities_GetVulnerabilities]
(
	@FeedType_Name VARCHAR(20) = NULL,
	@Search_Text VARCHAR(200) = NULL,
	@AssessmentType_Name NVARCHAR(200) = NULL,
	@OrderBy_Name  VARCHAR(MAX) = NULL, /* Title, Package, Assessment, Expiration, Score */
	@OrderByDesc_Indicator YNINDICATOR = NULL,
	@Skip_Count INT = NULL,
	@Take_Count INT = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	SET @Skip_Count = COALESCE(@Skip_Count, 0)
	SET @Take_Count = COALESCE(@Take_Count, 50)
	SET @OrderByDesc_Indicator = COALESCE(@OrderByDesc_Indicator, 'Y')

	;WITH FilteredVulnerabilities AS  
	(
		SELECT *, [Row_Number] = ROW_NUMBER() OVER (ORDER BY 
			(CASE 
				WHEN @OrderBy_Name = 'Title' AND @OrderByDesc_Indicator = 'N' THEN [Title_Text]
				WHEN @OrderBy_Name = 'Package' AND @OrderByDesc_Indicator = 'N' THEN [Package_Name]
				WHEN @OrderBy_Name = 'Assessment' AND @OrderByDesc_Indicator = 'N' THEN [AssessmentType_Name]
				ELSE ''
			END) ASC,
			(CASE 
				WHEN @OrderBy_Name = 'Title' AND @OrderByDesc_Indicator = 'Y' THEN [Title_Text]
				WHEN @OrderBy_Name = 'Package' AND @OrderByDesc_Indicator = 'Y' THEN [Package_Name]
				WHEN @OrderBy_Name = 'Assessment' AND @OrderByDesc_Indicator = 'Y' THEN [AssessmentType_Name]
				ELSE ''
			END) DESC,
			(CASE 
				WHEN @OrderBy_Name = 'Expiration' AND @OrderByDesc_Indicator = 'N' THEN [ExpiresOn_Date]
				ELSE NULL
			END) ASC,
			(CASE 
				WHEN @OrderBy_Name = 'Expiration' AND @OrderByDesc_Indicator = 'Y' THEN [ExpiresOn_Date]
				ELSE NULL
			END) DESC,
			(CASE 
				WHEN @OrderBy_Name = 'Score' AND @OrderByDesc_Indicator = 'N' THEN [Score]
				ELSE NULL
			END) ASC,
			(CASE 
				WHEN @OrderBy_Name = 'Score' AND @OrderByDesc_Indicator = 'Y' THEN [Score]
				ELSE NULL
			END) DESC,
			(CASE
				WHEN @OrderBy_Name IS NULL THEN [Vulnerability_Id]
				ELSE NULL
			END) DESC
		)
		FROM [Vulnerabilities_Extended]
		WHERE (@FeedType_Name IS NULL OR [FeedType_Name] = @FeedType_Name)
			AND (
				@Search_Text IS NULL 
				OR [Package_Name] LIKE '%' + @Search_Text + '%' 
				OR [Blob_Digest] LIKE '%' + @Search_Text + '%' 
				OR [Title_Text] LIKE '%' +  @Search_Text + '%'
			)
			AND (@AssessmentType_Name IS NULL OR [AssessmentType_Name] = @AssessmentType_Name)
	)
	SELECT * FROM FilteredVulnerabilities
		 WHERE [Row_Number] BETWEEN @Skip_Count AND @Skip_Count + @Take_Count

END
GO

GRANT EXECUTE ON [Vulnerabilities_GetVulnerabilities] TO [ProGetUser_Role]
GO